# rm::data_structures::history
# history module
# http://www.openehr.org/uml/release-1.0.1/Browsable/_9_0_76d0249_1109157527311_729550_7234Report.html
# refs #55
include OpenEHR::RM::DataStructures
include OpenEHR::RM::Common::Archetyped

module OpenEHR
  module RM
    module DataStructures
      module History
        class History < DataStructure
          attr_reader :origin, :events
          attr_accessor :duration, :period, :summary

          def initialize(args = { })
            super(args)
            self.origin = args[:origin]
            self.duration = args[:duration]
            self.period = args[:period]
            self.events = args[:events]
            self.summary = args[:summary]
          end

          def origin=(origin)
            raise ArgumentError, 'origin is mandatory' if origin.nil?
            @origin = origin
          end

          def events=(events)
            if !events.nil? and events.empty?
              raise ArgumentError, 'events should not be empty'
            end
            @events = events
          end

          def is_periodic?
            return !@period.nil?
          end
        end

        class Event < Locatable
          attr_reader :data, :time
          attr_accessor :state

          def initialize(args = { })
            super(args)
            self.data = args[:data]
            self.time = args[:time]
            self.state = args[:state]
          end

          def data=(data)
            raise ArgumentError, 'data is mandatory' if data.nil?
            @data = data
          end

          def time=(time)
            raise ArgumentError, 'time is mandatory' if time.nil?
            @time = time
          end

          def offset
            return @time.diff(@parent.origin)
          end
        end
      end # end of History
    end # end of DataStructure
  end # end of RM
end # end of OpenEHR
